
data{
  int P;                        //Number of items
  int N;                        //Number of persons
  int Number_of_responses;      //Overall number of responses
  int Categories[P];            //Number of response categories per item -1
  
  int Questionnaire[Number_of_responses]; //Questionnaire of each response
  int ID[Number_of_responses];            //Respondent for each response
  int Item[Number_of_responses];          //Item of each response
  int Response[Number_of_responses];      //actual response
  
  vector[P] prior_alpha;                  //mean for slope parameter priors
  vector[sum(Categories)] prior_kappa;    //mean for threshold parameter priors
  int Borders[P+1];                       //helper to identify item boundaries in threshold prior vector
  real prior_sd;                          //prior width
}

parameters {
  vector[sum(Categories)] kappa;          //threshold parameters    
  vector<lower=0>[P] alpha;               //slope parameters 
  
  vector[3] Means;                        //theta means for each questionnaire
  matrix[N, 3] theta;                     //individual thetas, one for each questionnaire
  cov_matrix[3] sigma;                    //covariance matrix
}

transformed parameters{
  vector[sum(Categories)] kappa_star;     
  vector[Number_of_responses] theta_star;
  
  for (i in 1:P){                         //sort kappa when threshold samples are not in order
    kappa_star[(Borders[i]+1):Borders[i+1]] = (-1) * sort_desc(kappa[(Borders[i]+1):Borders[i+1]]);
  }
  
  for (n in 1:Number_of_responses){       //assign the respective theta to each response
    if (Questionnaire[n] == 1) theta_star[n] = theta[ID[n],1];
    if (Questionnaire[n] == 2) theta_star[n] = theta[ID[n],2];
    if (Questionnaire[n] == 3) theta_star[n] = theta[ID[n],3];
  }
}


model {
  Means ~ normal(0,1);                    //standard normal hyperprior on overall theta means
  for (i in 1:N)                          //normal prior on individual thetas
    theta[i,] ~ multi_normal(Means, sigma); 
 
  alpha ~ normal(prior_alpha , prior_sd); //normal prior on slope parameter
  kappa ~ normal(prior_kappa, prior_sd);  //normal prior on threshold parameter

  for (n in 1:Number_of_responses){
    Response[n] ~ ordered_logistic(theta_star[n]* alpha[Item[n]], kappa_star[(Borders[Item[n]]+1):Borders[Item[n]+1]]);
  }
}

generated quantities{
  vector[2] differences;          //sample differences between theta directly from posterior
  differences[1] = mean(theta[,3] - theta[,1]); 
  differences[2] = mean(theta[,3] - theta[,2]);
}
