library(rstan)
rstan_options(auto_write = TRUE)
options(mc.cores = parallel::detectCores())

### LOAD DATA AND PARAMETERS ###
responses = read.csv("Item_Responses.csv") 
item_parameters = read.csv("Item_Parameters.csv")

### DEFINE VARIABLES NEEDED IN STAN MODEL ### 
N = length(unique(responses$ID))
P = length(unique(responses$variable))
Categories = tapply(responses$value, responses$variable, max)-1
Borders = c(0, cumsum(Categories))
Number_of_responses = nrow(responses)
Questionnaire = responses$Questionnaire
Response = responses$value
ID = responses$ID
Item = as.numeric(responses$variable)
prior_alpha = item_parameters[item_parameters$name == "a1","value"]
prior_kappa = item_parameters[item_parameters$name != "a1","value"]

### DEFINE START VALUES ###
start_values = list(
  alpha = prior_alpha + rnorm(length(prior_alpha),0,prior_sd), 
  kappa = prior_kappa + rnorm(length(prior_kappa),0,prior_sd))

start = list(start_values, start_values, start_values)

### DEFINE PRIOR WIDTH
prior_sd = .1

### SAMPLE THREE CORRELATED LATENT VARIABLES MODEL ###
three_correlated_latent_variables_model = stan_model("Bayesian_GRM_three_correlated_latent_variables.stan")
model_3cor_1 = sampling(three_correlated_latent_variables_model, pars = c("Means", "sigma", "differences", "alpha", "kappa_star", "theta"), init = start, chains = 3, iter = 5000, warmup = 1000)

### SAMPLE ONE LATENT VARIABLE MODEL ###
one_latent_variable_model = stan_model("Bayesian_GRM_one_latent_variable.stan")
model_1l_1 = sampling(one_latent_variable_model, pars = c("theta_mean", "theta_sd", "alpha", "kappa_star", "theta"), chains = 3, init = start, iter = 5000, warmup = 1000)